# PyMetEireann

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/DylanGore/PyMetEireann/Publish%20Python%20%F0%9F%90%8D%20distributions%20%F0%9F%93%A6%20to%20PyPI?style=for-the-badge)
![GitHub](https://img.shields.io/github/license/DylanGore/PyMetEireann?style=for-the-badge)
![PyPI](https://img.shields.io/pypi/v/PyMetEireann?style=for-the-badge)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/PyMetEireann?style=for-the-badge)

A Python library to communicate with the [Met Éireann](https://www.met.ie/) Public [Weather Forecast API](https://data.gov.ie/dataset/met-eireann-weather-forecast-api) and [Weather Warning API](https://data.gov.ie/dataset/weather-warnings).

The project is an independant fork of [pyMetno](https://github.com/Danielhiversen/pyMetno) by [Daniel Hjelseth Høyer](https://github.com/Danielhiversen/pyMetno/). It is in no way affiliated with or endorsed by Met Éireann.

## License

The PyMetEireann library is licensed under the MIT License.

The data provided by the API is licensed under the Met Eireann Custom Open Data Licence, the basic requirements of the license are described at [https://data.gov.ie/dataset/met-eireann-weather-forecast-api](https://data.gov.ie/dataset/met-eireann-weather-forecast-api). The full license is available [here](https://www.met.ie/cms/assets/uploads/2018/05/Met-%C3%89ireann-Open-Data-Custom-Licence_Final.odt).
